@@ -6,7 +6,7 @@
   
   qformat <- 
     "
-      SELECT spid,chemical.chid,casn,chnm
+      SELECT spid,chemical.chid,casn,chnm,dsstox_substance_id
       FROM sample LEFT JOIN chemical ON chemical.chid=sample.chid
       "
       
@@ -18,6 +18,7 @@
                    casn = "casn",
                    code = "casn",
                    chem.only = 'chem.only',
+                   dsstox_substance_id = "dsstox_substance_id",
                    "chnm")
     
     if (field == "code") val <- suppressWarnings(sapply(val, tcplCode2CASN))
