@@ -117,8 +117,32 @@ sc2_mthds <- function() {
       e1 <- bquote(coff <- c(coff, log2(1.5)))
       list(e1)
       
-    }
+    },
+  	
+    pc25 = function() {
+      
+      e1 <- bquote(coff <- c(coff, 25))
+      list(e1)
+
+    },    
     
+    ow_bmad_nwells = function() {
+      
+      e1 <- bquote(dat[ , bmad := mad(resp[wllt == "n"], na.rm = TRUE)])
+      list(e1)
+    },
+     bmad2 = function() {
+      
+      e1 <- bquote(coff <- c(coff, dat[ , unique(bmad)*2]))
+      list(e1)
+      
+    },
+    
+    log2_0.76 = function() {
+      
+      e1 <- bquote(coff <- c(coff, 0.76))
+      list(e1)
+    }
   )
 }
 
