@@ -6,9 +6,8 @@
 #' 
 #' @import DBI
 #' @import data.table
-#' @importFrom RMySQL MySQL
+#' @importFrom RMariaDB MariaDB
 #' @importFrom sqldf sqldf
-#' @importMethodsFrom RMySQL dbConnect dbDisconnect 
 #' @export
 
 
@@ -34,11 +33,12 @@ tcplQuery <- function(query, db = getOption("TCPL_DB"),
            "?tcplConf for more details.")
     }
     
-    db_pars <- list(drv = RMySQL::MySQL(),
+    db_pars <- list(drv = RMariaDB::MariaDB(),
                     user = getOption("TCPL_USER"),
                     password = getOption("TCPL_PASS"),
                     host = getOption("TCPL_HOST"),
-                    dbname = db)
+                    dbname = db,
+                    bigint = "numeric")
     
   }
   
